==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/NewStateTransitionSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.NewStateTransition;
import io.ciera.tool.sql.ooaofooa.statemachine.NewStateTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateEventMatrixEntrySet;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateEventMatrixEntrySetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.TransitionSetImpl;

import java.util.Arrays;
import java.util.List;


public class NewStateTransitionSetImpl extends InstanceSet<NewStateTransitionSet,NewStateTransition> implements NewStateTransitionSet {

    // attributes
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( NewStateTransition newstatetransition : this ) newstatetransition.setSMevt_ID( ref_SMevt_ID );
    }
    @Override
    public void setTrans_ID( UniqueId ref_Trans_ID ) throws XtumlException {
        for ( NewStateTransition newstatetransition : this ) newstatetransition.setTrans_ID( ref_Trans_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( NewStateTransition newstatetransition : this ) newstatetransition.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException {
        for ( NewStateTransition newstatetransition : this ) newstatetransition.setSMspd_IDdeprecated( m_SMspd_IDdeprecated );
    }
    @Override
    public void setSMstt_ID( UniqueId ref_SMstt_ID ) throws XtumlException {
        for ( NewStateTransition newstatetransition : this ) newstatetransition.setSMstt_ID( ref_SMstt_ID );
    }


    // selections
    @Override
    public StateEventMatrixEntrySet R504_is_a_StateEventMatrixEntry() throws XtumlException {
        StateEventMatrixEntrySet stateeventmatrixentryset = new StateEventMatrixEntrySetImpl();
        for ( NewStateTransition newstatetransition : this ) stateeventmatrixentryset.add( newstatetransition.R504_is_a_StateEventMatrixEntry() );
        return stateeventmatrixentryset;
    }
    @Override
    public TransitionSet R507_is_a_Transition() throws XtumlException {
        TransitionSet transitionset = new TransitionSetImpl();
        for ( NewStateTransition newstatetransition : this ) transitionset.add( newstatetransition.R507_is_a_Transition() );
        return transitionset;
    }


    @Override
    public NewStateTransition nullElement() {
        return NewStateTransitionImpl.EMPTY_NEWSTATETRANSITION;
    }

    @Override
    public NewStateTransitionSet emptySet() {
      return new NewStateTransitionSetImpl();
    }

    @Override
    public NewStateTransitionSet value() {
        return this;
    }

    @Override
    public List<NewStateTransition> elements() {
        return Arrays.asList(toArray(new NewStateTransition[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/NewStateTransitionSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.NewStateTransition;
import io.ciera.tool.sql.ooaofooa.statemachine.NewStateTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateEventMatrixEntrySet;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateEventMatrixEntrySetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.TransitionSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class NewStateTransitionSetImpl extends InstanceSet<NewStateTransitionSet,NewStateTransition> implements NewStateTransitionSet {

    public NewStateTransitionSetImpl() {
    }

    public NewStateTransitionSetImpl(Comparator<? super NewStateTransition> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( NewStateTransition newstatetransition : this ) newstatetransition.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setSMstt_ID( UniqueId ref_SMstt_ID ) throws XtumlException {
        for ( NewStateTransition newstatetransition : this ) newstatetransition.setSMstt_ID( ref_SMstt_ID );
    }
    @Override
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException {
        for ( NewStateTransition newstatetransition : this ) newstatetransition.setSMspd_IDdeprecated( m_SMspd_IDdeprecated );
    }
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( NewStateTransition newstatetransition : this ) newstatetransition.setSMevt_ID( ref_SMevt_ID );
    }
    @Override
    public void setTrans_ID( UniqueId ref_Trans_ID ) throws XtumlException {
        for ( NewStateTransition newstatetransition : this ) newstatetransition.setTrans_ID( ref_Trans_ID );
    }


    // selections
    @Override
    public StateEventMatrixEntrySet R504_is_a_StateEventMatrixEntry() throws XtumlException {
        StateEventMatrixEntrySet stateeventmatrixentryset = new StateEventMatrixEntrySetImpl();
        for ( NewStateTransition newstatetransition : this ) stateeventmatrixentryset.add( newstatetransition.R504_is_a_StateEventMatrixEntry() );
        return stateeventmatrixentryset;
    }
    @Override
    public TransitionSet R507_is_a_Transition() throws XtumlException {
        TransitionSet transitionset = new TransitionSetImpl();
        for ( NewStateTransition newstatetransition : this ) transitionset.add( newstatetransition.R507_is_a_Transition() );
        return transitionset;
    }


    @Override
    public NewStateTransition nullElement() {
        return NewStateTransitionImpl.EMPTY_NEWSTATETRANSITION;
    }

    @Override
    public NewStateTransitionSet emptySet() {
      return new NewStateTransitionSetImpl();
    }

    @Override
    public NewStateTransitionSet emptySet(Comparator<? super NewStateTransition> comp) {
      return new NewStateTransitionSetImpl(comp);
    }

    @Override
    public NewStateTransitionSet value() {
        return this;
    }

    @Override
    public List<NewStateTransition> elements() {
        return Arrays.asList(toArray(new NewStateTransition[0]));
    }

}
